@@ -50,7 +50,8 @@ def yamlDump(data, stream):
 def mproc_apply(func, iterLst, descr='', iterArgPos=0,
                 extraArgs=(), showProgress=True, applyAsync=True,
                 total=None, pool=None,
-                debug=False):
+                debug=False,
+                **extraKwargs):
   if total is None:
     try:
       total = len(iterLst)
@@ -79,7 +80,8 @@ def mproc_apply(func, iterLst, descr='', iterArgPos=0,
       pool = mp.Pool()
     if applyAsync:
       def applyFunc(func_, args):
-        return pool.apply_async(func_, args, callback=callback, error_callback=lambda ex: errCallback(args, ex))
+        return pool.apply_async(func_, args, kwds=extraKwargs,
+                                callback=callback, error_callback=lambda ex: errCallback(args, ex))
     else:
       applyFunc = pool.apply
 
