@@ -3,7 +3,7 @@ from __future__ import annotations
 import copy as _copy
 import inspect
 import typing as t
-from abc import ABC, abstractmethod
+from abc import ABC
 from functools import wraps
 from warnings import warn
 
@@ -120,7 +120,7 @@ class ProcessStage(ABC):
   allowDisable = False
   disabled = False
   cacheOnDisable = False
-  result: ProcessIO = None
+  result: t.Optional[ProcessIO] = None
   inMap: t.Union[t.List[str], t.Dict[str, str]] = None
   outMap: t.Union[t.List[str], t.Dict[str, str]] = None
 
@@ -139,6 +139,8 @@ class ProcessStage(ABC):
     return repr(self)
 
   def __eq__(self, other: NestedProcess):
+    if not isinstance(other, NestedProcess):
+      return False
     return pg.eq(self.saveState(True, True), other.saveState(True, True))
 
   def __hash__(self):
@@ -253,6 +255,9 @@ class AtomicProcess(ProcessStage):
     self.inMap = inMap or self.inMap
     self.outMap = outMap or self.outMap
 
+    self.cacheOnEq = True
+    """Whether equal inputs should result in a cached output rather than recomputing"""
+
     self.name = name
     try:
       self.input = ProcessIO.fromFunction(docFunc or func, **procIoKwargs)
@@ -323,7 +328,21 @@ class AtomicProcess(ProcessStage):
 
   def run(self, io: ProcessIO=None, disable=False, **runKwargs):
     disable = disable or self.disabled
+    oldInput = self.input.copy()
     self.updateInput(io, **runKwargs)
+    # Cast to dict since pyqtgraph thinks different types are unequal
+    try:
+      cmp = self.cacheOnEq and pg.eq(oldInput, dict(self.input))
+    except Exception as ex:
+      # Thrown exception is broad on pg equality comparison, so check the message
+      if '==' in str(ex):
+        cmp = False
+      else:
+        raise
+
+    if cmp and self.result is not None:
+      # Hypothetically the result should be the same
+      return self.result
     if not disable:
       out = self.func(**self.input)
       if self.outMap and not isinstance(out, ProcessIO):
@@ -551,44 +570,50 @@ class NestedProcess(ProcessStage):
         item.getViewBox().autoRange()
     QtCore.QTimer.singleShot(0, fixedShow)
 
-  def getStageInfos(self, ignoreDuplicates=True):
+  def getAllStageInfos(self, ignoreDuplicates=True, ignoreDisabled=True):
     allInfos: _infoType = []
     lastInfos = []
-    for stage in self._nonDisabledStages_flattened():
-      res = stage.result
-      if not isinstance(res, ProcessIO): continue
-      if any(k not in res for k in self.inMap):
-        # Missing required keys, not sure how to turn into summary info. Skip
+    stages = self._nonDisabledStages_flattened() if ignoreDisabled else self.stages_flattened
+    for stage in stages:
+      infos = self.singleStageInfo(stage)
+      if infos is None:
         continue
-      if 'summaryInfo' not in res:
-        defaultSummaryInfo = {k: res[k] for k in self.outMap}
-        defaultSummaryInfo.update(name=stage.name)
-        res['summaryInfo'] = defaultSummaryInfo
-      if res['summaryInfo'] is None:
-        continue
-      infos = stage.result['summaryInfo']
-      if not isinstance(infos, t.Sequence):
-        infos = [infos]
       if not ignoreDuplicates:
         validInfos = infos
       else:
         validInfos = self._cmpPrevCurInfos(lastInfos, infos)
       lastInfos = infos
-      for info in validInfos:
-        stageNameCount = 0
-        if info.get('name', None) is None:
-          newName = stage.name
-          if stageNameCount > 0:
-            newName = f'{newName}#{stageNameCount}'
-          info['name'] = newName
-        stageNameCount += 1
       allInfos.extend(validInfos)
     return allInfos
 
+  def singleStageInfo(self, stage: AtomicProcess):
+    res = stage.result
+    if not isinstance(res, ProcessIO) or any(k not in res for k in self.outMap):
+      # Missing required keys, not sure how to turn into summary info. Skip
+      return
+    if 'summaryInfo' not in res:
+      defaultSummaryInfo = {k: res[k] for k in self.outMap}
+      defaultSummaryInfo.update(name=stage.name)
+      res['summaryInfo'] = defaultSummaryInfo
+    if res['summaryInfo'] is None:
+      return
+    infos = stage.result['summaryInfo']
+    if not isinstance(infos, t.Sequence):
+      infos = [infos]
+    stageNameCount = 0
+    for info in infos:
+      if info.get('name', None) is None:
+        newName = stage.name
+        if stageNameCount > 0:
+          newName = f'{newName}#{stageNameCount}'
+        info['name'] = newName
+      stageNameCount += 1
+    return infos
+
   @classmethod
   def _cmpPrevCurInfos(cls, prevInfos: t.List[dict], infos: t.List[dict]):
     """
-    This comparison allows keys from the last result which exactly match keyts from the
+    This comparison allows keys from the last result which exactly match keys from the
     current result to be discarded for brevity.
     """
     validInfos = []
